Generic cup competitions
========================

The goal of this package is to provide high-quality models of knockout cup
competitions.

Currently, this package models standard single-elimination brackets for
team counts that are powers of two (4, 8, 16, etc.) and stepladder-style
brackets for any number of teams.

Changes in v0.2
---------------

- Stepladder cup brackets for any number of teams

Changes in v0.1
---------------

- Single-elimination brackets for powers of two (4, 8, 16, etc.)

.. image:: https://travis-ci.org/happy5214/competitions-cup.svg?branch=master
    :alt: Build status
    :target: https://travis-ci.org/happy5214/competitions-cup
.. image:: https://coveralls.io/repos/happy5214/competitions-cup/badge.svg?branch=master&service=github
    :alt: Coverage status
    :target: https://coveralls.io/github/happy5214/competitions-cup?branch=master
